@@ -37,12 +37,12 @@ changed, @reminder.date in 2 weeks
 class Action(models.Model):
     description = models.CharField(max_length=255)
 
-    def __str__(self):
-        return self.description
-
     def run(self, object):
         raise NotImplementedError()
 
+    def __str__(self):
+        return self.description
+
     class Meta:
         verbose_name = _("Action")
         verbose_name_plural = _("Actions")
@@ -99,6 +99,7 @@ class SendEmail(Action):
 
 
 class Trigger(models.Model):
+    description = models.CharField(max_length=255)
     model = models.ForeignKey(
         ContentType,
         verbose_name=_("Model"),
@@ -108,6 +109,9 @@ class Trigger(models.Model):
     enable = models.BooleanField(default=True)
     action = models.ForeignKey(Action, on_delete=models.PROTECT)
 
+    def __str__(self):
+        return self.description
+
     class Meta:
         abstract = True
 
@@ -122,9 +126,6 @@ class DataChangeTrigger(Trigger):
         ),
     )
 
-    def __str__(self):
-        return f"{self.model} Trigger: {self.action} when {self.type})"
-
     class Meta:
         verbose_name = _("Data change trigger")
         verbose_name_plural = _("Data change triggers")
@@ -175,13 +176,6 @@ class DateFieldTrigger(Trigger):
 
         return field_value + INTERVAL_CHOICES[self.offset_type][0] * self.offset_amount
 
-    def __str__(self):
-        return (
-            f"{self.model} Trigger: {self.action} on: {abs(self.offset_amount)} "
-            "{self.get_offset_type_display()} {'before' if self.offset_amount < 0 else 'after'} "
-            "{self.model}.{self.field})"
-        )
-
     class Meta:
         verbose_name = _("Date field trigger")
         verbose_name_plural = _("Date field triggers")
