@@ -2,7 +2,6 @@ from typing import List, NamedTuple, Optional, Union
 
 import htmlgenerator as hg
 from django.db import models
-from htmlgenerator import Lazy
 
 from .urls import model_urlname
 from .urls import reverse as urlreverse
@@ -25,20 +24,21 @@ class LazyHref(hg.Lazy):
 
     def resolve(self, context: dict):
         kwargs = {k: hg.resolve_lazy(v, context) for k, v in self.kwargs.items()}
-        # the django reverse function requires url-keyword arguments to be pass in a parameter named
-        # "kwarg". This is a bit confusing since kwargs normally referse to the python keyword arguments
-        # and not to URL keyword arguments. However, we also want to support lazy URL keywords, so we do the
-        # resolving of the actualy URL-kwargs as well
+        # the django reverse function requires url-keyword arguments to be pass
+        # in a parameter named "kwarg". This is a bit confusing since kwargs
+        # normally referse to the python keyword arguments and not to URL
+        # keyword arguments. However, we also want to support lazy URL
+        # keywords, so we do the resolving of the actualy URL-kwargs as well
         if "kwargs" in kwargs:
             kwargs["kwargs"] = {
                 k: hg.resolve_lazy(v, context) for k, v in kwargs["kwargs"].items()
             }
+        if "args" in kwargs:
+            kwargs["args"] = [hg.resolve_lazy(arg, context) for arg in kwargs["args"]]
         if "query" in kwargs:
             kwargs["query"] = {
                 k: hg.resolve_lazy(v, context) for k, v in kwargs["query"].items()
             }
-        if "args" in kwargs:
-            kwargs["args"] = [hg.resolve_lazy(arg, context) for arg in kwargs["args"]]
         return urlreverse(*[hg.resolve_lazy(a, context) for a in self.args], **kwargs)
 
 
@@ -53,32 +53,56 @@ class ModelHref(LazyHref):
     Example usage:
 
         assert "/person/browse" == ModelHref(models.Person, "browse").resolve(context)
-        assert "/person/edit/1" == ModelHref(models.Person, "edit", kwargs={"pk": hg.C("object.pk")}).resolve(context)
+        assert "/person/edit/1" == ModelHref(
+            models.Person, "edit", kwargs={"pk": hg.C("object.pk")}
+        ).resolve(context)
+
+    return_to_current: will add a URL query parameter "next=<current_url" to the generated URL
 
     """
 
-    def __init__(self, model, name, *args, **kwargs):
+    def __init__(
+        self,
+        model: Union[models.Model, hg.Lazy],
+        name: str,
+        *args,
+        return_to_current: bool = False,
+        **kwargs
+    ):
+
         # if this is an instance of a model, we can extract the pk URL argument directly
         # TODO: instance-specific routes which don't use the pk argument will fail
-        if isinstance(model, models.Model) and "pk" not in kwargs.get("kwargs", {}):
-            if "kwargs" not in kwargs:
-                kwargs["kwargs"] = {}
-            kwargs["kwargs"]["pk"] = model.pk
-
         if isinstance(model, hg.Lazy):
             url = hg.F(lambda c: model_urlname(hg.resolve_lazy(model, c), name))
         else:
             url = model_urlname(model, name)
+        if return_to_current:
+            if "query" not in kwargs:
+                kwargs["query"] = {}
+            kwargs["query"]["next"] = hg.C("request.get_full_path")
 
         super().__init__(url, *args, **kwargs)
 
+    @staticmethod
+    def from_object(object: Union[models.Model, hg.Lazy], name: str, *args, **kwargs):
+        """
+        name: string which denotes an object action name as generated
+              by bread.utils.urls.model_urlname
+        object: instance of a Model, can be lazy
+        """
+
+        if "kwargs" not in kwargs:
+            kwargs["kwargs"] = {}
+        kwargs["kwargs"]["pk"] = object.pk
+        return ModelHref(object, name, *args, **kwargs)
+
 
 def try_call(var, *args, **kwargs):
     return var(*args, **kwargs) if callable(var) else var
 
 
 class Link(NamedTuple):
-    href: Union[str, Lazy]
+    href: Union[str, hg.Lazy]
     label: str
     iconname: Optional[str] = "fade"
     permissions: List[str] = []
