@@ -9,11 +9,73 @@ from django.http import HttpResponse
 from django.urls import NoReverseMatch
 from django.utils.html import mark_safe
 from django.utils.module_loading import import_string
+from django.utils.translation import gettext_lazy as _
 
 from .. import layout as breadlayout
 from .. import menu
 from ..forms.forms import breadmodelform_factory
-from ..utils import filter_fieldlist, reverse_model
+from ..utils import ModelHref, filter_fieldlist, reverse_model
+
+R = breadlayout.grid.Row
+C = breadlayout.grid.Col
+
+
+def header():
+
+    editbutton = breadlayout.button.Button(
+        _("Edit"),
+        buttontype="ghost",
+        icon="edit",
+        notext=True,
+    ).as_href(ModelHref.from_object(hg.C("object"), "edit"))
+    readbutton = breadlayout.button.Button(
+        _("Read"),
+        buttontype="ghost",
+        icon="view",
+        notext=True,
+    ).as_href(ModelHref.from_object(hg.C("object"), "read"))
+
+    deletebutton = breadlayout.button.Button(
+        _("Delete"),
+        buttontype="tertiary",
+        icon="trash-can",
+        notext=True,
+        style="border-color: red; background-color: inherit",
+    ).as_href(ModelHref.from_object(hg.C("object"), "delete"))
+    deletebutton[1].attributes["style"] = "fill: red; color: red;"
+
+    copybutton = breadlayout.button.Button(
+        _("Copy"),
+        buttontype="ghost",
+        icon="copy",
+        notext=True,
+    ).as_href(ModelHref.from_object(hg.C("object"), "copy"))
+
+    return hg.DIV(
+        hg.H3(
+            hg.If(
+                hg.C("object"),
+                hg.BaseElement(
+                    hg.SPAN(hg.C("object")),
+                    hg.SPAN(
+                        hg.If(
+                            hg.C("request").resolver_match.url_name.endswith(".read"),
+                            editbutton,
+                            readbutton,
+                        ),
+                        copybutton,
+                        breadlayout.button.PrintPageButton(buttontype="ghost"),
+                        deletebutton,
+                        _class="no-print",
+                        style="margin-bottom: 1rem; margin-left: 1rem",
+                        width=3,
+                    ),
+                ),
+                hg.SPAN(hg.format(_("Add {}"), hg.C("view").model._meta.verbose_name)),
+            ),
+        ),
+        style="padding-top: 1rem",
+    )
 
 
 class CustomFormMixin:
@@ -58,10 +120,13 @@ class CustomFormMixin:
             return breadlayout.forms.Form(hg.C("form"), ret)
 
         # wrap with form will add a submit button
-        return hg.BaseElement(
-            hg.H3(self.object),
-            breadlayout.forms.Form(
-                hg.C("form"), ret, breadlayout.forms.helpers.Submit()
+        return hg.DIV(
+            header(),
+            breadlayout.tile.Tile(
+                breadlayout.forms.Form(
+                    hg.C("form"), ret, breadlayout.forms.helpers.Submit()
+                ),
+                _class="theme-white",
             ),
         )
 
